aboutsummaryrefslogtreecommitdiff
path: root/src/client/windows/handler
diff options
context:
space:
mode:
authormmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
committermmentovai <mmentovai@4c0a9323-5329-0410-9bdc-e9ce6186880e>2007-02-14 19:51:05 +0000
commite5dc60822e5938fea2ae892ccddb906641ba174e (patch)
treed7d4a8e94fee7bdb4eee6501221d92595ebd5f02 /src/client/windows/handler
parentChange the symbol table parsing so that it will only use symbols that are fro... (diff)
downloadbreakpad-e5dc60822e5938fea2ae892ccddb906641ba174e.tar.xz
Rename Airbag to Breakpad.
git-svn-id: http://google-breakpad.googlecode.com/svn/trunk@122 4c0a9323-5329-0410-9bdc-e9ce6186880e
Diffstat (limited to 'src/client/windows/handler')
-rw-r--r--src/client/windows/handler/exception_handler.cc32
-rw-r--r--src/client/windows/handler/exception_handler.h22
-rw-r--r--src/client/windows/handler/exception_handler.vcproj2
3 files changed, 28 insertions, 28 deletions
diff --git a/src/client/windows/handler/exception_handler.vcproj b/src/client/windows/handler/exception_handler.vcproj
index d76aca23..7e5998e4 100644
--- a/src/client/windows/handler/exception_handler.vcproj
+++ b/src/client/windows/handler/exception_handler.vcproj
@@ -295,7 +295,7 @@
>
</File>
<File
- RelativePath="..\..\..\google_airbag\common\minidump_format.h"
+ RelativePath="..\..\..\google_breakpad\common\minidump_format.h"
>
</File>
<File
diff --git a/src/client/windows/handler/exception_handler.cc b/src/client/windows/handler/exception_handler.cc
index d2220eb6..4e23ab1b 100644
--- a/src/client/windows/handler/exception_handler.cc
+++ b/src/client/windows/handler/exception_handler.cc
@@ -37,7 +37,7 @@
#include "client/windows/handler/exception_handler.h"
#include "common/windows/guid_string.h"
-namespace google_airbag {
+namespace google_breakpad {
static const int kExceptionHandlerThreadInitialStackSize = 64 * 1024;
@@ -144,7 +144,7 @@ ExceptionHandler::~ExceptionHandler() {
} else {
// TODO(mmentovai): use advapi32!ReportEvent to log the warning to the
// system's application event log.
- fprintf(stderr, "warning: removing Airbag handler out of order\n");
+ fprintf(stderr, "warning: removing Breakpad handler out of order\n");
for (vector<ExceptionHandler *>::iterator iterator =
handler_stack_->begin();
iterator != handler_stack_->end();
@@ -202,7 +202,7 @@ DWORD ExceptionHandler::ExceptionHandlerThreadMain(void *lpParameter) {
class AutoExceptionHandler {
public:
AutoExceptionHandler() {
// Increment handler_stack_index_ so that if another Airbag handler is
// registered using this same HandleException function, and it needs to be
// called while this handler is running (either becaause this handler
// declines to handle the exception, or an exception occurs during
@@ -415,23 +415,23 @@ bool ExceptionHandler::WriteMinidumpWithException(
except_info.ExceptionPointers = exinfo;
except_info.ClientPointers = FALSE;
// Add an MDRawAirbagInfo stream to the minidump, to provide additional
// information about the exception handler to the Airbag processor. The
// information will help the processor determine which threads are
// relevant. The Airbag processor does not require this information but
// can function better with Airbag-generated dumps when it is present.
// The native debugger is not harmed by the presence of this information.
- MDRawAirbagInfo airbag_info;
- airbag_info.validity = MD_AIRBAG_INFO_VALID_DUMP_THREAD_ID |
- MD_AIRBAG_INFO_VALID_REQUESTING_THREAD_ID;
- airbag_info.dump_thread_id = GetCurrentThreadId();
- airbag_info.requesting_thread_id = requesting_thread_id;
+ MDRawBreakpadInfo breakpad_info;
+ breakpad_info.validity = MD_BREAKPAD_INFO_VALID_DUMP_THREAD_ID |
+ MD_BREAKPAD_INFO_VALID_REQUESTING_THREAD_ID;
+ breakpad_info.dump_thread_id = GetCurrentThreadId();
+ breakpad_info.requesting_thread_id = requesting_thread_id;
// Leave room in user_stream_array for a possible assertion info stream.
MINIDUMP_USER_STREAM user_stream_array[2];
- user_stream_array[0].Type = MD_AIRBAG_INFO_STREAM;
- user_stream_array[0].BufferSize = sizeof(airbag_info);
- user_stream_array[0].Buffer = &airbag_info;
+ user_stream_array[0].Type = MD_BREAKPAD_INFO_STREAM;
+ user_stream_array[0].BufferSize = sizeof(breakpad_info);
+ user_stream_array[0].Buffer = &breakpad_info;
MINIDUMP_USER_STREAM_INFORMATION user_streams;
user_streams.UserStreamCount = 1;
@@ -479,4 +479,4 @@ void ExceptionHandler::UpdateNextID() {
next_minidump_path_c_ = next_minidump_path_.c_str();
}
-} // namespace google_airbag
+} // namespace google_breakpad
@@ -202,7 +202,7 @@ DWORD ExceptionHandler::ExceptionHandlerThreadMain(void *lpParameter) {
public:
AutoExceptionHandler() {
- // Increment handler_stack_index_ so that if another Airbag handler is
+ // Increment handler_stack_index_ so that if another Breakpad handler is
// registered using this same HandleException function, and it needs to be
// called while this handler is running (either becaause this handler
@@ -415,23 +415,23 @@ bool ExceptionHandler::WriteMinidumpWithException(
except_info.ExceptionPointers = exinfo;
except_info.ClientPointers = FALSE;
- // Add an MDRawAirbagInfo stream to the minidump, to provide additional
- // information about the exception handler to the Airbag processor. The
+ // Add an MDRawBreakpadInfo stream to the minidump, to provide additional
+ // information about the exception handler to the Breakpad processor. The
// information will help the processor determine which threads are
@@ -415,23 +415,23 @@ bool ExceptionHandler::WriteMinidumpWithException(
// information will help the processor determine which threads are
- // relevant. The Airbag processor does not require this information but
- // can function better with Airbag-generated dumps when it is present.
+ // relevant. The Breakpad processor does not require this information but
+ // can function better with Breakpad-generated dumps when it is present.
// The native debugger is not harmed by the presence of this information.
diff --git a/src/client/windows/handler/exception_handler.h b/src/client/windows/handler/exception_handler.h
index fb5ddf50..f7bfe6cb 100644
--- a/src/client/windows/handler/exception_handler.h
+++ b/src/client/windows/handler/exception_handler.h
@@ -70,24 +70,24 @@
#include <string>
#include <vector>
-#include "google_airbag/common/minidump_format.h"
+#include "google_breakpad/common/minidump_format.h"
-namespace google_airbag {
+namespace google_breakpad {
using std::vector;
using std::wstring;
class ExceptionHandler {
public:
// A callback function to run before Airbag performs any substantial
// processing of an exception. A FilterCallback is called before writing
// a minidump. context is the parameter supplied by the user as
// callback_context when the handler was created. exinfo points to the
// exception record, if any; assertion points to assertion information,
// if any.
//
// If a FilterCallback returns true, Airbag will continue processing,
// attempting to write a minidump. If a FilterCallback returns false, Airbag
// will immediately report the exception as unhandled without writing a
// minidump, allowing another handler the opportunity to handle it.
typedef bool (*FilterCallback)(void *context, EXCEPTION_POINTERS *exinfo,
@@ -102,11 +102,11 @@ class ExceptionHandler {
// assertion points to information about an assertion if the handler was
// invoked by an assertion.
//
// If an exception occurred and the callback returns true, Airbag will treat
// the exception as fully-handled, suppressing any other handlers from being
// notified of the exception. If the callback returns false, Airbag will
// treat the exception as unhandled, and allow another handler to handle it.
// If there are no other handlers, Airbag will report the exception to the
// system as unhandled, allowing a debugger or native crash dialog the
// opportunity to handle the exception. Most callback implementations
// should normally return the value of |succeeded|, or when they wish to
@@ -121,7 +121,7 @@ class ExceptionHandler {
// Creates a new ExceptionHandler instance to handle writing minidumps.
// Before writing a minidump, the optional filter callback will be called.
// Its return value determines whether or not Airbag should write a minidump.
// Minidump files will be written to dump_path, and the optional callback
// is called after writing the dump file, as described above.
// If install_handler is true, then a minidump will be written whenever
@@ -298,7 +298,7 @@ class ExceptionHandler {
// The index of the ExceptionHandler in handler_stack_ that will handle the
// next exception. Note that 0 means the last entry in handler_stack_, 1
// means the next-to-last entry, and so on. This is used by HandleException
// to support multiple stacked Airbag handlers.
static LONG handler_stack_index_;
// handler_stack_critical_section_ guards operations on handler_stack_ and
@@ -313,7 +313,7 @@ class ExceptionHandler {
void operator=(const ExceptionHandler &);
};
-} // namespace google_airbag
+} // namespace google_breakpad
#pragma warning( pop )
@@ -70,24 +70,24 @@
class ExceptionHandler {
public:
- // A callback function to run before Airbag performs any substantial
+ // A callback function to run before Breakpad performs any substantial
// processing of an exception. A FilterCallback is called before writing
// a minidump. context is the parameter supplied by the user as
@@ -70,24 +70,24 @@
// if any.
//
- // If a FilterCallback returns true, Airbag will continue processing,
- // attempting to write a minidump. If a FilterCallback returns false, Airbag
+ // If a FilterCallback returns true, Breakpad will continue processing,
+ // attempting to write a minidump. If a FilterCallback returns false, Breakpad
// will immediately report the exception as unhandled without writing a
// minidump, allowing another handler the opportunity to handle it.
@@ -102,11 +102,11 @@ class ExceptionHandler {
// invoked by an assertion.
//
- // If an exception occurred and the callback returns true, Airbag will treat
+ // If an exception occurred and the callback returns true, Breakpad will treat
// the exception as fully-handled, suppressing any other handlers from being
@@ -102,11 +102,11 @@ class ExceptionHandler {
// the exception as fully-handled, suppressing any other handlers from being
- // notified of the exception. If the callback returns false, Airbag will
+ // notified of the exception. If the callback returns false, Breakpad will
// treat the exception as unhandled, and allow another handler to handle it.
@@ -102,11 +102,11 @@ class ExceptionHandler {
// treat the exception as unhandled, and allow another handler to handle it.
- // If there are no other handlers, Airbag will report the exception to the
+ // If there are no other handlers, Breakpad will report the exception to the
// system as unhandled, allowing a debugger or native crash dialog the
// opportunity to handle the exception. Most callback implementations
@@ -121,7 +121,7 @@ class ExceptionHandler {
// Creates a new ExceptionHandler instance to handle writing minidumps.
// Before writing a minidump, the optional filter callback will be called.
- // Its return value determines whether or not Airbag should write a minidump.
+ // Its return value determines whether or not Breakpad should write a minidump.
// Minidump files will be written to dump_path, and the optional callback
// is called after writing the dump file, as described above.
@@ -298,7 +298,7 @@ class ExceptionHandler {
// next exception. Note that 0 means the last entry in handler_stack_, 1
// means the next-to-last entry, and so on. This is used by HandleException
- // to support multiple stacked Airbag handlers.
+ // to support multiple stacked Breakpad handlers.
static LONG handler_stack_index_;
// handler_stack_critical_section_ guards operations on handler_stack_ and